import { Metadata } from "next";
import Link from "next/link";
import { buttonVariants } from "@/components/ui/button";
import { cn } from "@/lib/utils";
import Image from "next/image";
import SignUpForm from "@/components/forms/signup-form";

export const metadata: Metadata = {
  title: "Sign Up | Skilld",
  description: "Sign Up to start your journey with Skilld.",
};

export default function AuthenticationPage() {
  return (
    <div className="relative h-screen flex-col items-center justify-center md:grid lg:max-w-none lg:grid-cols-2 lg:px-0">
      <Link
        href="/signin"
        className={cn(
          buttonVariants({ variant: "ghost" }),
          "absolute right-4 top-4 md:right-8 md:top-8 hidden",
        )}
      >
        Sign In
      </Link>
      <div className="relative hidden h-full flex-col bg-secondary p-10 dark:border-r lg:flex">
        <div className="absolute inset-0 bg-secondary" />
        <Link
          href="/dashboard"
          className="relative z-20 flex items-center text-lg font-medium"
        >
          <Image
            src="/Skilld AI Logos/Skilld Logo-colour on black.png"
            alt="Skilld Logo"
            width={100}
            height={30}
            className="hidden dark:block h-[25px] w-[80px] md:w-[100px] md:h-[30px] object-contain"
          />
          <Image
            src="/Skilld AI Logos/Skilld Logo-colour.png"
            alt="Skilld Logo"
            width={100}
            height={30}
            className="dark:hidden h-[25px] w-[80px] md:w-[100px] md:h-[30px] object-contain"
          />
        </Link>
        {/* <div className="relative z-20 flex items-center text-lg font-medium">
          <svg
            xmlns="http://www.w3.org/2000/svg"
            viewBox="0 0 24 24"
            fill="none"
            stroke="currentColor"
            strokeWidth="2"
            strokeLinecap="round"
            strokeLinejoin="round"
            className="mr-2 h-6 w-6"
          >
            <path d="M15 6v12a3 3 0 1 0 3-3H6a3 3 0 1 0 3 3V6a3 3 0 1 0-3 3h12a3 3 0 1 0-3-3" />
          </svg>
          Skilld
        </div> */}
        <div className="relative z-20 mt-auto">
          <blockquote className="space-y-2">
            <p className="text-lg text-muted-foreground">
              &ldquo;Empower your coding journey at Skilld. Access tutorials,
              challenges, and expert-led courses to master programming languages
              and tools. Join a supportive community for discussions and code
              reviews. Elevate your skills and stay ahead in the tech world with
              us!.&rdquo;
            </p>
            {/* <footer className="text-sm">Ak</footer> */}
          </blockquote>
        </div>
      </div>
      <div className="p-4 lg:p-8 h-full flex items-center">
        <div className="mx-auto flex w-full flex-col justify-center space-y-6 sm:w-[350px]">
          <div className="flex flex-col space-y-2 text-center">
            <h1 className="text-2xl font-semibold tracking-tight">
              Create an account
            </h1>
            {/* <p className="text-sm text-muted-foreground">
              Enter your email and password below to create your account
            </p> */}
          </div>
          <SignUpForm />
          <div>
            <p className="text-center text-sm text-muted-foreground">
              Already have an account?{" "}
              <Link href="/signin" className="underline hover:text-primary">
                Sign In
              </Link>
            </p>
            <p className="mt-2 text-center text-sm text-muted-foreground">
              By clicking continue, you agree to our{" "}
              <Link
                href="/terms"
                className="underline underline-offset-4 hover:text-primary"
              >
                Terms of Service
              </Link>{" "}
              and{" "}
              <Link
                href="/privacy"
                className="underline underline-offset-4 hover:text-primary"
              >
                Privacy Policy
              </Link>
              .
            </p>
          </div>
        </div>
      </div>
    </div>
  );
}
